Glowing-waffles
===============

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

This is a package template provided by the Astropy project.

Using this template, packages can make use of the setup, installation, and documentation
infrastructure developed for the ``astropy`` core and affiliated packages.

For more information, see:

* `Detailed instructions for using this template <http://docs.astropy.org/en/latest/development/affiliated-packages.html>`_
* `The Affiliated Packages section of the Astropy web site <http://affiliated.astropy.org>`_
* `This template's Github code repository <https://github.com/astropy/package-template>`_

What do glowing waffles have to do with astronomy? Absolutely nothing.

Nonetheless, this is a package to do stellar photometry using `astropy`_ and
`astropy affiliated packages`_.

If you have an idea for a better name we are all ears...

.. _astropy: http://astropy.org
.. _astropy affiliated packages: http://www.astropy.org/affiliated/index.html
